summaryrefslogtreecommitdiffstats
path: root/src/Entities/Player.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/Entities/Player.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/Entities/Player.h b/src/Entities/Player.h
index 83b9ad593..165963e6e 100644
--- a/src/Entities/Player.h
+++ b/src/Entities/Player.h
@@ -194,9 +194,18 @@ public:
// Sets the current gamemode, doesn't check validity, doesn't send update packets to client
void LoginSetGameMode(eGameMode a_GameMode);
/** Forces the player to move in the given direction. */
void ForceSetSpeed(const Vector3d & a_Speed); // tolua_export
+ /** Sets the speed of the player and moves them in the given speed. */
+ void SetSpeed (const Vector3d & a_Speed);
+ virtual void SetSpeed (double a_SpeedX, double a_SpeedY, double a_SpeedZ) override;
+ virtual void SetSpeedX (double a_SpeedX) override;
+ virtual void SetSpeedY (double a_SpeedY) override;
+ virtual void SetSpeedZ (double a_SpeedZ) override;
+
/** Tries to move to a new position, with attachment-related checks (y == -999) */
void MoveTo(const Vector3d & a_NewPos); // tolua_export
@@ -194,9 +194,18 @@ public:
// Sets the current gamemode, doesn't check validity, doesn't send update packets to client
void LoginSetGameMode(eGameMode a_GameMode);
- /** Forces the player to move in the given direction. */
+ /** Forces the player to move in the given direction.
+ * @deprecated Use SetSpeed instead.
+ */
void ForceSetSpeed(const Vector3d & a_Speed); // tolua_export